@@ -15,7 +15,7 @@
 
 #[cfg(all(test, feature = "unstable"))] extern crate test;
 #[cfg(feature = "log-events")] extern crate rustc_serialize;
-#[cfg(feature = "heapsize")] #[macro_use] extern crate heapsize;
+#[cfg(feature = "heapsize")] extern crate heapsize;
 #[cfg(test)] extern crate rand;
 #[macro_use] extern crate lazy_static;
 #[macro_use] extern crate debug_unreachable;
